energy library
Provides type-safe units for Energy.
Import this file to use Energy quantities and their
extensions on num (like 500.J, 250.kcal, 1.2.kWh).
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
- Energy
- Represents a quantity of energy.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
Enums
- EnergyUnit
- Represents units of energy.
Extensions
- EnergyCreation on num
- Provides convenient factory methods for creating Energy instances from num using getter properties named after common unit symbols or names.
- EnergyValueGetters on Energy
- Provides convenient access to Energy values in specific units using getter properties.