frequency library
Provides type-safe units for Frequency.
Import this file to use Frequency quantities and their
extensions on num (like 4.2.ghz, 120.bpm, 60.freqRpm).
Note: If you also import angular_velocity.dart, the .rpm getter
will conflict. In that case, use the main quantify.dart barrel (which
resolves the conflict by defaulting .rpm to 'AngularVelocity') or hide
one of the extensions manually.
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
- Frequency
- Represents a quantity of frequency.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
Enums
- FrequencyUnit
- Represents units of frequency.
Extensions
- FrequencyCreation on num
- Provides convenient factory methods for creating Frequency instances from num.
- FrequencyValueGetters on Frequency
- Provides convenient access to Frequency values in specific units.