fuel_consumption library
Provides type-safe units for fuel consumption and fuel economy.
Import this file to use inverse fuel consumption quantities and their num
extensions like 5.6.LPer100Km or 42.mpg.
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
- FuelConsumption
- Represents fuel consumption and fuel economy.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
Enums
- FuelConsumptionUnit
- Represents units of fuel consumption and fuel economy.
Extensions
- FuelConsumptionCreation on num
- Provides convenient factory methods for creating FuelConsumption instances.
- FuelConsumptionValueGetters on FuelConsumption
- Provides convenient access to FuelConsumption values in specific units.