information library
Provides type-safe units for Information (bits, bytes, SI and IEC).
Import this file to use Information quantities and their
extensions on num (like 10.MB, 5.GiB).
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
- Information
- Represents a physical quantity of digital information.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
Enums
- InformationUnit
- Represents units of digital information.
Extensions
- InformationCreation on num
- Provides convenient factory methods for creating Information instances from num.
- InformationValueGetters on Information
- Provides convenient access to Information values in specific units.