power library

Provides type-safe units for Power.

Import this file to use Power quantities and their extensions on num (like 100.kW, 250.hp, 1.2.gigaW).

Classes

AffineQuantity<T extends Unit<T>, Q extends AffineQuantity<T, Q>>
Base class for quantities whose conversions are affine instead of purely multiplicative.
InverseQuantity<T extends Unit<T>, Q extends InverseQuantity<T, Q>>
Base class for quantities whose conversions route through a reciprocal canonical form.
LinearQuantity<T extends LinearUnit<T>, Q extends LinearQuantity<T, Q>>
An abstract base class for physical quantities with linear (factor-based) unit conversions.
LinearUnit<T extends LinearUnit<T>>
A contract for units that scale linearly (via a simple multiplier).
LogarithmicQuantity<T extends Unit<T>, Q extends LogarithmicQuantity<T, Q>>
Base class for quantities that represent logarithmic levels of another physical dimension.
Power
Represents a quantity of power.
Quantity<T extends Unit<T>>
An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
Unit<T extends Unit<T>>
A base contract for all unit enums.

Enums

PowerUnit
Represents units of power.

Extensions

PowerCreation on num
Provides convenient factory methods for creating Power instances from num.
PowerValueGetters on Power
Provides convenient access to Power values in specific units using getter properties.