AreaUnit enum

Represents units of area.

This enum implements the LinearUnit interface to provide conversion capabilities and a display symbol for each area unit. All conversion factors are pre-calculated in the constructor relative to Square Meter (m²).

Inheritance
Implemented types
Available extensions

Values

squareMeter → const AreaUnit

Square Meter (m²), the SI derived unit of area.

const AreaUnit(1, 'm²')
squareDecimeter → const AreaUnit

Square Decimeter (dm²).

const AreaUnit(AreaFactors.dm2, 'dm²')
squareCentimeter → const AreaUnit

Square Centimeter (cm²).

const AreaUnit(AreaFactors.cm2, 'cm²')
squareMillimeter → const AreaUnit

Square Millimeter (mm²).

const AreaUnit(AreaFactors.mm2, 'mm²')
squareMicrometer → const AreaUnit

Square Micrometer (µm²).

const AreaUnit(AreaFactors.um2, 'µm²')
squareDecameter → const AreaUnit

Square Decameter (dam²).

const AreaUnit(AreaFactors.dam2, 'dam²')
squareHectometer → const AreaUnit

Square Hectometer (hm²).

const AreaUnit(AreaFactors.hm2, 'hm²')
hectare → const AreaUnit

Hectare (ha), a common unit for land area, equal to 10,000 m².

const AreaUnit(AreaFactors.hm2, 'ha')
squareKilometer → const AreaUnit

Square Kilometer (km²).

const AreaUnit(AreaFactors.km2, 'km²')
squareMegameter → const AreaUnit

Square Megameter (Mm²).

const AreaUnit(AreaFactors.Mm2, 'Mm²')
squareInch → const AreaUnit

Square Inch (in²).

const AreaUnit(AreaFactors.in2, 'in²')
squareFoot → const AreaUnit

Square Foot (ft²).

const AreaUnit(AreaFactors.ft2, 'ft²')
squareYard → const AreaUnit

Square Yard (yd²).

const AreaUnit(AreaFactors.yd2, 'yd²')
squareMile → const AreaUnit

Square Mile (mi²).

const AreaUnit(AreaFactors.mi2, 'mi²')
acre → const AreaUnit

Acre (ac).

const AreaUnit(AreaFactors.ac, 'ac')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isMetric bool
Returns false for imperial/US customary land-area units and for hectare (a unit accepted for use with the SI, not a prefixed square metre); true for all decimal multiples/submultiples of the square metre.
no setteroverride
isSI bool
Returns true only for squareMeter, the SI derived unit of area.
no setteroverride
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
A human-readable symbol or abbreviation for the unit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<AreaUnit>
A constant List of the values in this enum, in order of their declaration.