CurrentCreation extension

Provides convenient factory methods for creating Current instances from num using getter properties named after common unit symbols or names.

on

Properties

A Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Amperes (A).
no setter
abA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance from this numerical value in Abamperes (abA).
no setter
abamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance from this numerical value in Abamperes (abA). Alias for abA, also known as Biot (Bi).
no setter
amperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Amperes (A). Alias for A.
no setter
bi Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance from this numerical value in Biot (Bi). This is an alias for Abampere (abA).
no setter
fA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Femtoamperes (fA).
no setter
femtoamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Femtoamperes (fA). Alias for fA.
no setter
GA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Gigaamperes (GA).
no setter
gigaamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Gigaamperes (GA). Alias for GA.
no setter
kA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Kiloamperes (kA).
no setter
kiloamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Kiloamperes (kA). Alias for kA.
no setter
MA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Megaamperes (MA).
no setter
mA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Milliamperes (mA).
no setter
megaamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Megaamperes (MA). Alias for MA.
no setter
microamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Microamperes (µA). Alias for uA.
no setter
milliamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Milliamperes (mA). Alias for mA.
no setter
nA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Nanoamperes (nA).
no setter
nanoamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Nanoamperes (nA). Alias for nA.
no setter
pA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Picoamperes (pA).
no setter
picoamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Picoamperes (pA). Alias for pA.
no setter
statA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance from this numerical value in Statamperes (statA).
no setter
statamperes Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance from this numerical value in Statamperes (statA). Alias for statA.
no setter
uA Current

Available on num, provided by the CurrentCreation extension

Creates a Current instance representing this numerical value in Microamperes (µA).
no setter