CurrentValueGetters extension

Provides convenient access to Current values in specific units using getter properties.

on

Properties

asAbamperes Current

Available on Current, provided by the CurrentValueGetters extension

Returns a new Current object representing this current in Abamperes (abA) or Biot (Bi).
no setter
asAmperes Current

Available on Current, provided by the CurrentValueGetters extension

Returns a new Current object representing this current in Amperes (A).
no setter
asKiloamperes Current

Available on Current, provided by the CurrentValueGetters extension

Returns a new Current object representing this current in Kiloamperes (kA).
no setter
asMicroamperes Current

Available on Current, provided by the CurrentValueGetters extension

Returns a new Current object representing this current in Microamperes (µA).
no setter
asMilliamperes Current

Available on Current, provided by the CurrentValueGetters extension

Returns a new Current object representing this current in Milliamperes (mA).
no setter
asNanoamperes Current

Available on Current, provided by the CurrentValueGetters extension

Returns a new Current object representing this current in Nanoamperes (nA).
no setter
asStatamperes Current

Available on Current, provided by the CurrentValueGetters extension

Returns a new Current object representing this current in Statamperes (statA).
no setter
inAbamperes double

Available on Current, provided by the CurrentValueGetters extension

Returns the electric current value in Abamperes (abA) or Biot (Bi).
no setter
inAmperes double

Available on Current, provided by the CurrentValueGetters extension

Returns the electric current value in Amperes (A).
no setter
inKiloamperes double

Available on Current, provided by the CurrentValueGetters extension

Returns the electric current value in Kiloamperes (kA).
no setter
inMicroamperes double

Available on Current, provided by the CurrentValueGetters extension

Returns the electric current value in Microamperes (µA).
no setter
inMilliamperes double

Available on Current, provided by the CurrentValueGetters extension

Returns the electric current value in Milliamperes (mA).
no setter
inNanoamperes double

Available on Current, provided by the CurrentValueGetters extension

Returns the electric current value in Nanoamperes (nA).
no setter
inStatamperes double

Available on Current, provided by the CurrentValueGetters extension

Returns the electric current value in Statamperes (statA).
no setter