ElectricChargeValueGetters extension

Provides convenient access to ElectricCharge values in specific units.

on

Properties

asAbcoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Abcoulombs (abC).
no setter
asAmpereHours ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Ampere-hours (Ah).
no setter
asCoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Coulombs (C).
no setter
asElementaryCharges ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Elementary Charges (e).
no setter
asKilocoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Kilocoulombs (kC).
no setter
asMicrocoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Microcoulombs (µC).
no setter
asMilliampereHours ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Milliampere-hours (mAh).
no setter
asMillicoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Millicoulombs (mC).
no setter
asNanocoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Nanocoulombs (nC).
no setter
asPicocoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Picocoulombs (pC).
no setter
asStatcoulombs ElectricCharge

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns a new ElectricCharge object representing this charge in Statcoulombs (statC).
no setter
inAbcoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Abcoulombs (abC).
no setter
inAmpereHours double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Ampere-hours (Ah).
no setter
inCoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Coulombs (C).
no setter
inElementaryCharges double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Elementary Charges (e).
no setter
inKilocoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Kilocoulombs (kC).
no setter
inMicrocoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Microcoulombs (µC).
no setter
inMilliampereHours double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Milliampere-hours (mAh).
no setter
inMillicoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Millicoulombs (mC).
no setter
inNanocoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Nanocoulombs (nC).
no setter
inPicocoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Picocoulombs (pC).
no setter
inStatcoulombs double

Available on ElectricCharge, provided by the ElectricChargeValueGetters extension

Returns the electric charge value in Statcoulombs (statC).
no setter