EnergyCreation extension

Provides convenient factory methods for creating Energy instances from num using getter properties named after common unit symbols or names.

This allows for an intuitive and concise way to create energy quantities, for example: 250.kcal or 1.2.kWh.

on

Properties

britishThermalUnits Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in British Thermal Units (Btu). Alias for btu.
no setter
btu Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in British Thermal Units (Btu).
no setter
cal Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Calories (cal).
no setter
calIT Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in International Table Calories (cal_IT).
no setter
calories Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Calories (cal).
no setter
caloriesIT Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in International Table Calories (cal_IT).
no setter
electronvolts Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Electronvolts (eV).
no setter
eV Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Electronvolts (eV).
no setter
gigajoules Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Gigajoules (GJ).
no setter
GJ Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Gigajoules (GJ).
no setter
J Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Joules (J).
no setter
joules Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Joules (J).
no setter
kcal Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Kilocalories (kcal).
no setter
kcalIT Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in International Table Kilocalories (kcal_IT).
no setter
kilocalories Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Kilocalories (kcal).
no setter
kilocaloriesIT Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in International Table Kilocalories (kcal_IT).
no setter
kilojoules Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Kilojoules (kJ).
no setter
kilowattHours Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Kilowatt-hours (kWh).
no setter
kJ Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Kilojoules (kJ).
no setter
kWh Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Kilowatt-hours (kWh).
no setter
megajoules Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Megajoules (MJ). Dart-idiomatic alias for the SI symbol MJ.
no setter
microjoules Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Microjoules (µJ).
no setter
millijoules Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Millijoules (mJ).
no setter
MJ Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Megajoules (MJ).
no setter
mJ Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Millijoules (mJ).
no setter
terajoules Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Terajoules (TJ).
no setter
TJ Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Terajoules (TJ).
no setter
uJ Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Microjoules (µJ).
no setter
wattHours Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Watt-hours (Wh).
no setter
Wh Energy

Available on num, provided by the EnergyCreation extension

Creates an Energy instance from this value in Watt-hours (Wh).
no setter