FrequencyCreation extension

Provides convenient factory methods for creating Frequency instances from num.

on

Properties

bpm Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Beats per minute (bpm).
no setter
degPerSec Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Degrees per second (°/s).
no setter
freqRpm Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Revolutions per minute (rpm).
no setter
GHz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Gigahertz (GHz).
no setter
gigahertz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Gigahertz (GHz). Dart-idiomatic alias for the SI symbol GHz.
no setter
hertz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Hertz (Hz). Dart-idiomatic alias for the SI symbol Hz.
no setter
Hz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Hertz (Hz).
no setter
kHz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Kilohertz (kHz).
no setter
kilohertz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Kilohertz (kHz). Dart-idiomatic alias for the SI symbol kHz.
no setter
megahertz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Megahertz (MHz). Dart-idiomatic alias for the SI symbol MHz.
no setter
MHz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Megahertz (MHz).
no setter
mHz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Millihertz (mHz).
no setter
millihertz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Millihertz (mHz). Alias for mHz.
no setter
radPerSec Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Radians per second (rad/s).
no setter
terahertz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Terahertz (THz). Dart-idiomatic alias for the SI symbol THz.
no setter
THz Frequency

Available on num, provided by the FrequencyCreation extension

Creates a Frequency instance from this value in Terahertz (THz).
no setter