InformationCreation extension

Provides convenient factory methods for creating Information instances from num.

on

Properties

bit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Bits.
no setter
bits Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Bits. Alias for bit.
no setter
byte Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Bytes (B).
no setter
bytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Bytes (B). Alias for byte.
no setter
EB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Exabytes (EB, SI: 10¹⁸ bytes).
no setter
eb Information

Available on num, provided by the InformationCreation extension

Lowercase alias for EB — exabytes (SI: 10¹⁸ bytes).
no setter
Ebit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Exabits (Ebit, SI: 10¹⁸ bits).
no setter
EiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Exbibytes (EiB, IEC: 2⁶⁰ bytes).
no setter
eib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for EiB — exbibytes (IEC: 2⁶⁰ bytes).
no setter
GB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Gigabytes (GB, SI: 10⁹ bytes).
no setter
gb Information

Available on num, provided by the InformationCreation extension

Lowercase alias — gigabits (SI: 10⁹ bits). Use GB or .gigabytes for gigabytes.
no setter
Gbit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Gigabits (Gbit, SI: 10⁹ bits).
no setter
GiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Gibibytes (GiB, IEC: 2³⁰ bytes).
no setter
gib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for GiB — gibibytes (IEC: 2³⁰ bytes).
no setter
gibibytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Gibibytes (GiB, IEC: 2³⁰ bytes). Alias for GiB.
no setter
gigabytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Gigabytes (GB, SI: 10⁹ bytes). Alias for GB.
no setter
kB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Kilobytes (kB, SI: 1 000 bytes).
no setter
kb Information

Available on num, provided by the InformationCreation extension

Lowercase alias — kilobits (SI: 10³ bits). Use kB or .kilobytes for kilobytes.
no setter
kbit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Kilobits (kbit, SI: 1 000 bits).
no setter
KiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Kibibytes (KiB, IEC: 1 024 bytes).
no setter
kib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for KiB — kibibytes (IEC: 1 024 bytes).
no setter
kibibytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Kibibytes (KiB, IEC: 1 024 bytes). Alias for KiB.
no setter
kilobytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Kilobytes (kB, SI: 1 000 bytes). Alias for kB.
no setter
MB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Megabytes (MB, SI: 10⁶ bytes).
no setter
mb Information

Available on num, provided by the InformationCreation extension

Lowercase alias — megabits (SI: 10⁶ bits). Use MB or .megabytes for megabytes.
no setter
Mbit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Megabits (Mbit, SI: 10⁶ bits).
no setter
mebibytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Mebibytes (MiB, IEC: 2²⁰ bytes). Alias for MiB.
no setter
megabytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Megabytes (MB, SI: 10⁶ bytes). Alias for MB.
no setter
MiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Mebibytes (MiB, IEC: 2²⁰ bytes).
no setter
mib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for MiB — mebibytes (IEC: 2²⁰ bytes).
no setter
PB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Petabytes (PB, SI: 10¹⁵ bytes).
no setter
pb Information

Available on num, provided by the InformationCreation extension

Lowercase alias — petabits (SI: 10¹⁵ bits). Use PB or .petabytes for petabytes.
no setter
Pbit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Petabits (Pbit, SI: 10¹⁵ bits).
no setter
PiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Pebibytes (PiB, IEC: 2⁵⁰ bytes).
no setter
pib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for PiB — pebibytes (IEC: 2⁵⁰ bytes).
no setter
TB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Terabytes (TB, SI: 10¹² bytes).
no setter
tb Information

Available on num, provided by the InformationCreation extension

Lowercase alias — terabits (SI: 10¹² bits). Use TB or .terabytes for terabytes.
no setter
Tbit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Terabits (Tbit, SI: 10¹² bits).
no setter
tebibytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Tebibytes (TiB, IEC: 2⁴⁰ bytes). Alias for TiB.
no setter
terabytes Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Terabytes (TB, SI: 10¹² bytes). Alias for TB.
no setter
TiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Tebibytes (TiB, IEC: 2⁴⁰ bytes).
no setter
tib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for TiB — tebibytes (IEC: 2⁴⁰ bytes).
no setter
YB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Yottabytes (YB, SI: 10²⁴ bytes).
no setter
yb Information

Available on num, provided by the InformationCreation extension

Lowercase alias for YB — yottabytes (SI: 10²⁴ bytes).
no setter
Ybit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Yottabits (Ybit, SI: 10²⁴ bits).
no setter
YiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Yobibytes (YiB, IEC: 2⁸⁰ bytes).
no setter
yib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for YiB — yobibytes (IEC: 2⁸⁰ bytes).
no setter
ZB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Zettabytes (ZB, SI: 10²¹ bytes).
no setter
zb Information

Available on num, provided by the InformationCreation extension

Lowercase alias for ZB — zettabytes (SI: 10²¹ bytes).
no setter
Zbit Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Zettabits (Zbit, SI: 10²¹ bits).
no setter
ZiB Information

Available on num, provided by the InformationCreation extension

Creates an Information instance representing this value in Zebibytes (ZiB, IEC: 2⁷⁰ bytes).
no setter
zib Information

Available on num, provided by the InformationCreation extension

Lowercase alias for ZiB — zebibytes (IEC: 2⁷⁰ bytes).
no setter