asGbit property
Information
get
asGbit
Returns an Information representing this quantity in Gigabits (Gbit).
Implementation
Information get asGbit => convertTo(InformationUnit.gigabit);
Returns an Information representing this quantity in Gigabits (Gbit).
Information get asGbit => convertTo(InformationUnit.gigabit);