asMegaM property
Length
get
asMegaM
Returns a Length representing this length in Megameters (Mm).
Implementation
Length get asMegaM => convertTo(LengthUnit.megameter);
Returns a Length representing this length in Megameters (Mm).
Length get asMegaM => convertTo(LengthUnit.megameter);