asYd property
Length
get
asYd
Returns a Length representing this length in Yards (yd).
Implementation
Length get asYd => convertTo(LengthUnit.yard);
Returns a Length representing this length in Yards (yd).
Length get asYd => convertTo(LengthUnit.yard);