MolarAmountValueGetters extension

Provides convenient access to MolarAmount values in specific units using getter properties.

These getters simplify retrieving the numerical value of a molar amount in a desired unit without explicitly calling getValue().

on

Properties

asFemtomoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Femtomoles (fmol).
no setter
asKilomoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Kilomoles (kmol).
no setter
asMegamoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Megamoles (Mmol).
no setter
asMicromoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Micromoles (µmol).
no setter
asMillimoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Millimoles (mmol).
no setter
asMoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Moles (mol).
no setter
asNanomoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Nanomoles (nmol).
no setter
asPicomoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Picomoles (pmol).
no setter
asPoundMoles MolarAmount

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns a new MolarAmount object representing this amount in Pound-moles (lb-mol).
no setter
inFemtomoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Femtomoles (fmol).
no setter
inKilomoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Kilomoles (kmol).
no setter
inMegamoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Megamoles (Mmol).
no setter
inMicromoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Micromoles (µmol).
no setter
inMillimoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Millimoles (mmol).
no setter
inMoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Moles (mol).
no setter
inNanomoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Nanomoles (nmol).
no setter
inPicomoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Picomoles (pmol).
no setter
inPoundMoles double

Available on MolarAmount, provided by the MolarAmountValueGetters extension

Returns the molar amount value in Pound-moles (lb-mol).
no setter