PowerLevelUnit enum
Represents units of absolute power level.
PowerLevelUnit models logarithmic power referenced either to one
milliwatt (dBm) or one watt (dBW).
- Inheritance
- Implemented types
- Available extensions
Values
- dBm → const PowerLevelUnit
-
Decibels referenced to one milliwatt.
const PowerLevelUnit('dBm') - dBW → const PowerLevelUnit
-
Decibels referenced to one watt.
const PowerLevelUnit('dBW')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
The display symbol for this power level unit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
values
→ const List<
PowerLevelUnit> - A constant List of the values in this enum, in order of their declaration.