asAtm property
Pressure
get
asAtm
Returns a Pressure representing this pressure in Atmospheres (atm).
Implementation
Pressure get asAtm => convertTo(PressureUnit.atmosphere);
Returns a Pressure representing this pressure in Atmospheres (atm).
Pressure get asAtm => convertTo(PressureUnit.atmosphere);