ResistanceCreation extension

Provides convenient factory methods for creating Resistance instances from num using getter properties named after common unit symbols or names.

on

Properties

gigaohms Resistance

Available on num, provided by the ResistanceCreation extension

Creates a Resistance instance representing this numerical value in Gigaohms (GΩ).
no setter
kiloohms Resistance

Available on num, provided by the ResistanceCreation extension

Creates a Resistance instance representing this numerical value in Kiloohms (kΩ).
no setter
megaohms Resistance

Available on num, provided by the ResistanceCreation extension

Creates a Resistance instance representing this numerical value in Megaohms (MΩ).
no setter
microohms Resistance

Available on num, provided by the ResistanceCreation extension

Creates a Resistance instance representing this numerical value in Microohms (µΩ).
no setter
milliohms Resistance

Available on num, provided by the ResistanceCreation extension

Creates a Resistance instance representing this numerical value in Milliohms (mΩ).
no setter
nanoohms Resistance

Available on num, provided by the ResistanceCreation extension

Creates a Resistance instance representing this numerical value in Nanoohms (nΩ).
no setter
ohms Resistance

Available on num, provided by the ResistanceCreation extension

Creates a Resistance instance representing this numerical value in Ohms (Ω).
no setter