SpeedUnit enum

Represents units of speed.

This enum implements the LinearUnit interface to provide conversion capabilities and a display symbol for each speed unit. All conversion factors are pre-calculated in the constructor relative to Meter per Second (m/s).

Inheritance
Implemented types
Available extensions

Values

meterPerSecond → const SpeedUnit

Meter per second (m/s), the SI derived unit of speed.

const SpeedUnit(1, 'm/s')
kilometerPerSecond → const SpeedUnit

Kilometer per second (km/s), a common unit in scientific contexts like astronomy.

const SpeedUnit(SpeedFactors.mpsPerKps, 'km/s')
kilometerPerHour → const SpeedUnit

Kilometer per hour (km/h), a common unit for road vehicle speed.

const SpeedUnit(SpeedFactors.mpsPerKmh, 'km/h')
milePerHour → const SpeedUnit

Mile per hour (mph), a common unit for road vehicle speed in some countries.

const SpeedUnit(SpeedFactors.mpsPerMph, 'mph')
knot → const SpeedUnit

Knot (kn), a unit of speed equal to one nautical mile per hour. Commonly used in maritime and aviation contexts.

const SpeedUnit(SpeedFactors.mpsPerKnot, 'kn')
footPerSecond → const SpeedUnit

Foot per second (ft/s), used in some engineering contexts.

const SpeedUnit(SpeedFactors.mpsPerFps, 'ft/s')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isMetric bool
Returns false for the imperial milePerHour and footPerSecond, the nautical knot, and kilometerPerHour (contains the non-metric hour); true for meterPerSecond and kilometerPerSecond.
no setteroverride
isSI bool
Returns true only for meterPerSecond, the SI derived unit of speed.
no setteroverride
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
A human-readable symbol or abbreviation for the unit.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

nameAliases → const Map<String, SpeedUnit>
Case-insensitive name aliases for parsing (all lowercase).
symbolAliases → const Map<String, SpeedUnit>
Case-sensitive symbol aliases for parsing.
values → const List<SpeedUnit>
A constant List of the values in this enum, in order of their declaration.