asMegaseconds property
Time
get
asMegaseconds
Returns a Time representing this time in Megaseconds (Ms).
Implementation
Time get asMegaseconds => convertTo(TimeUnit.megasecond);
Returns a Time representing this time in Megaseconds (Ms).
Time get asMegaseconds => convertTo(TimeUnit.megasecond);