asNanoseconds property
Time
get
asNanoseconds
Returns a Time representing this time in Nanoseconds (ns).
Implementation
Time get asNanoseconds => convertTo(TimeUnit.nanosecond);
Returns a Time representing this time in Nanoseconds (ns).
Time get asNanoseconds => convertTo(TimeUnit.nanosecond);