VoltageUnit enum

Represents units for electric potential (voltage).

This enum implements the LinearUnit interface to provide conversion capabilities and a display symbol for each voltage unit. All conversion factors are pre-calculated in the constructor relative to Volt (V), which is the SI derived unit for electric potential.

Inheritance
Implemented types
Available extensions

Values

volt → const VoltageUnit

Volt (V), the SI derived unit of electric potential. Defined as one joule per coulomb (J/C), or equivalently one watt per ampere (W/A).

const VoltageUnit(1, 'V')
nanovolt → const VoltageUnit

Nanovolt (nV), equal to 1e-9 volts.

const VoltageUnit(VoltageFactors.voltsPerNanovolt, 'nV')
microvolt → const VoltageUnit

Microvolt (µV), equal to 1e-6 volts.

const VoltageUnit(VoltageFactors.voltsPerMicrovolt, 'µV')
millivolt → const VoltageUnit

Millivolt (mV), equal to 0.001 volts.

const VoltageUnit(VoltageFactors.voltsPerMillivolt, 'mV')
kilovolt → const VoltageUnit

Kilovolt (kV), equal to 1000 volts.

const VoltageUnit(VoltageFactors.voltsPerKilovolt, 'kV')
megavolt → const VoltageUnit

Megavolt (MV), equal to 1,000,000 volts.

const VoltageUnit(VoltageFactors.voltsPerMegavolt, 'MV')
gigavolt → const VoltageUnit

Gigavolt (GV), equal to 1,000,000,000 volts.

const VoltageUnit(VoltageFactors.voltsPerGigavolt, 'GV')
statvolt → const VoltageUnit

Statvolt (statV), the CGS electrostatic unit of electric potential.

const VoltageUnit(VoltageFactors.voltsPerStatvolt, 'statV')
abvolt → const VoltageUnit

Abvolt (abV), the CGS electromagnetic unit of electric potential.

const VoltageUnit(VoltageFactors.voltsPerAbvolt, 'abV')

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
isMetric bool
Returns false for the CGS units statvolt and abvolt; true for all decimal metric units.
no setteroverride
isSI bool
Returns true only for volt, the SI derived unit of electric potential.
no setteroverride
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
symbol String
The human-readable symbol for this voltage unit (e.g., "V", "mV").
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<VoltageUnit>
A constant List of the values in this enum, in order of their declaration.