VolumeCreation extension

Provides convenient factory methods for creating Volume instances from num using getter properties named after common unit symbols or names.

on

Properties

centiliters Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Centiliters (cL). Alias for cL.
no setter
cL Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Centiliters (cL).
no setter
cm3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Centimeters (cm³).
no setter
cubicFeet Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Feet (ft³). Alias for ft3.
no setter
cubicInches Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Inches (in³). Alias for in3.
no setter
cubicMeters Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Meters (m³). Alias for m3.
no setter
dam3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Decameters (dam³).
no setter
dm3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Decimeters (dm³).
no setter
flOz Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Fluid Ounces (fl-oz).
no setter
fluidOunce Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Fluid Ounces (fl-oz). Alias for flOz. Singular form for natural English syntax (e.g., 1.fluidOunce).
no setter
ft3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Feet (ft³).
no setter
gal Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Gallons (gal).
no setter
gallon Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Gallons (gal). Alias for gal. Singular form for natural English syntax (e.g., 1.gallon).
no setter
gallons Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Gallons (gal). Alias for gal.
no setter
gigaliters Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Gigaliters (Gl). Alias for Gl.
no setter
Gl Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Gigaliters (Gl).
no setter
hm3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Hectometers (hm³).
no setter
imperialGallon Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in UK (Imperial) Gallons. Alias for ukGal. Singular form for natural English syntax.
no setter
imperialGallons Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in UK (Imperial) Gallons. Alias for ukGal.
no setter
in3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Inches (in³).
no setter
kl Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Kiloliters (kl).
no setter
km3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Kilometers (km³).
no setter
L Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Liters (L).
no setter
liters Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Liters (L). Alias for L.
no setter
m3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Meters (m³).
no setter
megaliters Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Megaliters (Ml). Alias for Ml.
no setter
mi3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Miles (mi³).
no setter
milliliters Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Milliliters (mL). Alias for mL.
no setter
Ml Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Megaliters (Ml).
no setter
mL Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Milliliters (mL).
no setter
mm3 Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Cubic Millimeters (mm³).
no setter
pint Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Pints (pt). Alias for pt. Singular form for natural English syntax (e.g., 1.pint).
no setter
pints Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Pints (pt). Alias for pt.
no setter
pt Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Pints (pt).
no setter
qt Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Quarts (qt).
no setter
quart Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Quarts (qt). Alias for qt. Singular form for natural English syntax (e.g., 1.quart).
no setter
quarts Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Quarts (qt). Alias for qt.
no setter
tablespoons Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Tablespoons (tbsp). Alias for tbsp.
no setter
tbsp Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Tablespoons (tbsp).
no setter
teaspoons Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Teaspoons (tsp). Alias for tsp.
no setter
teraliters Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Teraliters (Tl). Alias for Tl.
no setter
Tl Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Teraliters (Tl).
no setter
tsp Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in US Teaspoons (tsp).
no setter
ukGal Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in UK (Imperial) Gallons.
no setter
uL Volume

Available on num, provided by the VolumeCreation extension

Creates a Volume instance from this value in Microliters (µL).
no setter