speed library

Provides type-safe units for Speed.

Import this file to use Speed quantities and their extensions on num (like 100.kmh, 60.mph).

Classes

AffineQuantity<T extends Unit<T>, Q extends AffineQuantity<T, Q>>
Base class for quantities whose conversions are affine instead of purely multiplicative.
InverseQuantity<T extends Unit<T>, Q extends InverseQuantity<T, Q>>
Base class for quantities whose conversions route through a reciprocal canonical form.
LinearQuantity<T extends LinearUnit<T>, Q extends LinearQuantity<T, Q>>
An abstract base class for physical quantities with linear (factor-based) unit conversions.
LinearUnit<T extends LinearUnit<T>>
A contract for units that scale linearly (via a simple multiplier).
LogarithmicQuantity<T extends Unit<T>, Q extends LogarithmicQuantity<T, Q>>
Base class for quantities that represent logarithmic levels of another physical dimension.
Quantity<T extends Unit<T>>
An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
Speed
Represents a quantity of speed (or velocity).
Unit<T extends Unit<T>>
A base contract for all unit enums.

Enums

SpeedUnit
Represents units of speed.

Extensions

SpeedCreation on num
Provides convenient factory methods for creating Speed instances from num.
SpeedValueGetters on Speed
Provides convenient access to Speed values in specific units.