time library
Provides type-safe units for Time.
Import this file to use Time quantities and their
extensions on num (like 60.s, 1.5.h).
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
- Time
- Represents a quantity of time (duration).
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
Enums
- TimeUnit
- Represents units of time.
Extensions
- TimeCreation on num
- Provides convenient factory methods for creating Time instances from num.
- TimeValueGetters on Time
- Provides convenient access to Time values in specific units.