torque library

Granular export for the Torque quantity only.

Use this import to avoid pulling in the entire quantify library when only torque functionality is needed.

import 'package:quantify/torque.dart';

Classes

Torque
Represents a quantity of torque (rotational moment).

Enums

TorqueUnit
Represents units of torque.

Extensions

TorqueCreation on num
Provides convenient factory methods for creating Torque instances from num.
TorqueValueGetters on Torque
Provides convenient access to Torque values in specific units.