volume library
Provides type-safe units for Volume.
Import this file to use Volume quantities and their
extensions on num (like 1.5.l, 2.m3, 8.fl_oz).
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
- Volume
- Represents a quantity of volume.
Enums
- VolumeUnit
- Represents units of volume.
Extensions
- VolumeCreation on num
- Provides convenient factory methods for creating Volume instances from num using getter properties named after common unit symbols or names.
- VolumeValueGetters on Volume
- Provides convenient access to Volume values in specific units using getter properties.