angle library
Provides type-safe units for Angle.
Import this file to use Angle quantities and their
extensions on num (like 90.degrees, 1.5.radians).
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
- Angle
- Represents a quantity of a plane angle.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
Enums
- AngleUnit
- Represents units for a plane angle.
Extensions
- AngleCreation on num
- Provides convenient factory methods for creating Angle instances from num.
- AngleValueGetters on Angle
- Provides convenient access to Angle values in specific units.