EnergyDensityFactors class
Defines base conversion factors for various energy density units relative to the Joule per Cubic Meter (J/m³), which is the SI derived unit for energy density.
These constants represent: 1 [Unit] = Z [Joules Per Cubic Meter].
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- joulePerCubicMeter → const double
- Joules per Cubic Meter: 1 J/m³ = 1.0 J/m³.
- joulePerLiter → const double
- Joules per Liter: 1 J/L = 1000 J/m³ (since 1 L = 0.001 m³).
- wattHourPerLiter → const double
- Watt-hours per Liter: 1 Wh/L = 3,600,000 J/m³ (since 1 Wh = 3600 J and 1 L = 0.001 m³, so 1 Wh/L = 3600 J / 0.001 m³).