pressure library
Provides type-safe units for Pressure.
Import this file to use Pressure quantities and their
extensions on num (like 1.atm, 32.psi).
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
- Pressure
- Represents a quantity of pressure.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
Enums
- PressureUnit
- Represents units of pressure.
Extensions
- PressureCreation on num
- Provides convenient factory methods for creating Pressure instances from num using shortened unit names where appropriate.
- PressureValueGetters on Pressure
- Provides convenient access to Pressure values in specific units using shortened unit names where appropriate.