AreaCreation extension
Provides convenient factory methods for creating Area instances from num using getter properties named after common unit symbols or names.
This allows for an intuitive and concise way to create area quantities,
for example: 10.m2 or 5.ha.
- on
Properties
- ac → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Acres (ac).no setter - cm2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Centimeters (cm²).no setter - dam2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Decameters (dam²).no setter - dm2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Decimeters (dm²).no setter - ft2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Feet (ft²).no setter - ha → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Hectares (ha).no setter - hm2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Hectometers (hm²).no setter - in2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Inches (in²).no setter - km2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Kilometers (km²).no setter - m2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Meters (m²).no setter - mi2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Miles (mi²).no setter - Mm2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Megameters (Mm²).no setter - mm2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Millimeters (mm²).no setter - squareCentimeters → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Centimeters (cm²). Alias for cm2.no setter - squareFeet → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Feet (ft²). Alias for ft2.no setter - squareInches → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Inches (in²). Alias for in2.no setter - squareKilometers → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Kilometers (km²). Alias for km2.no setter - squareMeters → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Meters (m²). Alias for m2.no setter - squareMiles → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Miles (mi²). Alias for mi2.no setter - squareMillimeters → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Millimeters (mm²). Alias for mm2.no setter - squareYards → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Yards (yd²). Alias for yd2.no setter - um2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Micrometers (µm²).no setter - yd2 → Area
-
Available on num, provided by the AreaCreation extension
Creates an Area instance representing this numerical value in Square Yards (yd²).no setter