PowerCreation extension
- on
Properties
- britishThermalUnitsPerHour → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in British Thermal Units per hour (Btu/h). Alias for btuPerHour.no setter - btuPerHour → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in British Thermal Units per hour (Btu/h).no setter - ergPerSecond → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Ergs per second (erg/s).no setter - gigawatts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Gigawatts (GW).no setter - GW → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Gigawatts (GW).no setter - horsepower → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in mechanical Horsepower (hp). Alias for hp.no setter - hp → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in mechanical Horsepower (hp).no setter - kilowatts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Kilowatts (kW).no setter - kW → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Kilowatts (kW).no setter - megawatts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Megawatts (MW).no setter - metricHp → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in metric Horsepower (PS).no setter - microwatts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Microwatts (µW).no setter - milliwatts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Milliwatts (mW).no setter - MW → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Megawatts (MW).no setter - mW → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Milliwatts (mW).no setter - nanowatts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Nanowatts (nW).no setter - nW → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Nanowatts (nW).no setter - terawatts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Terawatts (TW).no setter - TW → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Terawatts (TW).no setter - uW → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Microwatts (µW).no setter - W → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Watts (W).no setter - watts → Power
-
Available on num, provided by the PowerCreation extension
Creates a Power instance from this value in Watts (W).no setter