PressureCreation extension
Provides convenient factory methods for creating Pressure instances from num using shortened unit names where appropriate.
- on
Properties
- atm → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Atmospheres (atm).no setter - atmospheres → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Atmospheres (atm). Alias for atm.no setter - bar → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Bars (bar).no setter - bars → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Bars (bar). Alias for bar.no setter - cmH2O → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Centimeters of Water (cmH₂O) at 4°C.no setter - GPa → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Gigapascals (GPa).no setter - hPa → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Hectopascals (hPa).no setter - inH2O → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Inches of Water (inH₂O) at 4°C.no setter - inHg → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Inches of Mercury (inHg).no setter - kilopascals → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Kilopascals (kPa). Dart-idiomatic alias for the SI symbol kPa.no setter - kPa → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Kilopascals (kPa).no setter - mbar → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Millibars (mbar).no setter - megapascals → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Megapascals (MPa). Dart-idiomatic alias for the SI symbol MPa.no setter - millimetersOfMercury → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Millimeters of Mercury (mmHg). Alias for mmHg.no setter - mmHg → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Millimeters of Mercury (mmHg).no setter - MPa → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Megapascals (MPa).no setter - Pa → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Pascals (Pa).no setter - pascals → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Pascals (Pa). Alias for Pa.no setter - psi → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Pounds per Square Inch (psi).no setter - torr → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Torrs (Torr).no setter - uPa → Pressure
-
Available on num, provided by the PressureCreation extension
Creates a Pressure instance representing this numerical value in Micropascals (µPa).no setter