ResistanceValueGetters extension
Provides convenient access to Resistance values in specific units using getter properties.
- on
Properties
- asGigaohms → Resistance
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns a new Resistance object representing this resistance in Gigaohms (GΩ).no setter - asKiloohms → Resistance
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns a new Resistance object representing this resistance in Kiloohms (kΩ).no setter - asMegaohms → Resistance
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns a new Resistance object representing this resistance in Megaohms (MΩ).no setter - asMicroohms → Resistance
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns a new Resistance object representing this resistance in Microohms (µΩ).no setter - asMilliohms → Resistance
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns a new Resistance object representing this resistance in Milliohms (mΩ).no setter - asNanoohms → Resistance
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns a new Resistance object representing this resistance in Nanoohms (nΩ).no setter - asOhms → Resistance
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns a new Resistance object representing this resistance in Ohms (Ω).no setter - inGigaohms → double
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns the resistance value in Gigaohms (GΩ).no setter - inKiloohms → double
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns the resistance value in Kiloohms (kΩ).no setter - inMegaohms → double
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns the resistance value in Megaohms (MΩ).no setter - inMicroohms → double
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns the resistance value in Microohms (µΩ).no setter - inMilliohms → double
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns the resistance value in Milliohms (mΩ).no setter - inNanoohms → double
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns the resistance value in Nanoohms (nΩ).no setter - inOhms → double
-
Available on Resistance, provided by the ResistanceValueGetters extension
Returns the resistance value in Ohms (Ω).no setter