TimeCreation extension
- on
Properties
- centuries → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Centuries (c). Note:.cis avoided due to conflict with 'centi' prefix and Celsius.no setter - cs → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Centiseconds (cs).no setter - d → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Days (d). Alias fordays.no setter - das → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Decaseconds (das).no setter - days → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Days (d).no setter - decades → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Decades (dec).no setter - ds → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Deciseconds (ds).no setter - fortnights → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Fortnights (fn).no setter - gigaS → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Gigaseconds (Gs).no setter - h → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Hours (h). Alias forhours.no setter - hours → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Hours (h).no setter - hs → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Hectoseconds (hs).no setter - kiloS → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Kiloseconds (ks).no setter - megaS → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance from this numerical value in Megaseconds (Ms).no setter - microseconds → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Microseconds (μs).no setter - milliseconds → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Milliseconds (ms).no setter - min → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Minutes (min). Alias forminutes. Note: 'm' is used for meters, so 'min' is better for time.no setter - minutes → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Minutes (min).no setter - mo → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Months (mo). Alias formonths.no setter - months → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Months (mo).no setter - ms → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Milliseconds (ms). Alias formilliseconds.no setter - nanoseconds → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Nanoseconds (ns).no setter - ns → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Nanoseconds (ns). Alias fornanoseconds.no setter - picoseconds → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Picoseconds (ps).no setter - ps → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Picoseconds (ps). Alias forpicoseconds.no setter - s → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Seconds (s). Alias forseconds.no setter - seconds → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Seconds (s).no setter - us → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Microseconds (μs). Alias formicroseconds.no setter - weeks → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Weeks (wk).no setter - wk → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Weeks (wk). Alias forweeks.no setter - years → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Years (yr).no setter - yr → Time
-
Available on num, provided by the TimeCreation extension
Creates a Time instance representing this numerical value in Years (yr). Alias foryears.no setter