VoltageCreation extension
Provides convenient factory methods for creating Voltage instances from num using getter properties named after common unit symbols or names.
- on
Properties
- abV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance from this numerical value in Abvolts (abV).no setter - abvolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance from this numerical value in Abvolts (abV). Alias forabV.no setter - gigavolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Gigavolts (GV). Alias forGV.no setter - GV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Gigavolts (GV).no setter - kilovolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Kilovolts (kV). Alias forkV.no setter - kV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Kilovolts (kV).no setter - megavolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Megavolts (MV). Alias forMV.no setter - microvolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Microvolts (µV). Alias foruV.no setter - millivolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Millivolts (mV). Alias formV.no setter - MV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Megavolts (MV).no setter - mV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Millivolts (mV).no setter - nanovolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Nanovolts (nV). Alias fornV.no setter - nV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Nanovolts (nV).no setter - statV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance from this numerical value in Statvolts (statV).no setter - statvolts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance from this numerical value in Statvolts (statV). Alias forstatV.no setter - uV → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Microvolts (µV).no setter - V → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Volts (V).no setter - volts → Voltage
-
Available on num, provided by the VoltageCreation extension
Creates a Voltage instance representing this numerical value in Volts (V). Alias forV.no setter