VolumetricFlowRateUnit enum
Represents units of volumetric flow rate.
This enum implements the LinearUnit interface to provide conversion capabilities and a display symbol for each volumetric flow rate unit. All conversion factors are pre-calculated in the constructor relative to Cubic Meter per Second (m³/s).
- Inheritance
- Implemented types
- Available extensions
Values
- cubicMeterPerSecond → const VolumetricFlowRateUnit
-
Cubic meter per second (m³/s), the SI derived unit of volumetric flow rate.
const VolumetricFlowRateUnit(1, 'm³/s') - cubicMeterPerMinute → const VolumetricFlowRateUnit
-
Cubic meter per minute (m³/min), commonly used in HVAC and industrial contexts.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerCmpm, 'm³/min') - cubicMeterPerHour → const VolumetricFlowRateUnit
-
Cubic meter per hour (m³/h), commonly used for pumps and industrial flow meters.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerCmph, 'm³/h') - literPerSecond → const VolumetricFlowRateUnit
-
Liter per second (L/s), commonly used for water flow and small pumps.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerLps, 'L/s') - literPerMinute → const VolumetricFlowRateUnit
-
Liter per minute (L/min), commonly used for household appliances and medical dosing.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerLpm, 'L/min') - literPerHour → const VolumetricFlowRateUnit
-
Liter per hour (L/h), commonly used for medical infusion rates and irrigation.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerLph, 'L/h') - milliliterPerMinute → const VolumetricFlowRateUnit
-
Milliliter per minute (mL/min), commonly used for medical infusion pumps.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerMlpm, 'mL/min') - cubicFootPerSecond → const VolumetricFlowRateUnit
-
Cubic foot per second (ft³/s, CFS), commonly used in hydrology and civil engineering.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerCfs, 'ft³/s') - cubicFootPerMinute → const VolumetricFlowRateUnit
-
Cubic foot per minute (ft³/min, CFM), commonly used for HVAC airflow.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerCfm, 'ft³/min') - gallonPerMinute → const VolumetricFlowRateUnit
-
US Gallon per minute (gal/min, GPM), commonly used for pumps in the US.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerGpm, 'gal/min') - gallonPerHour → const VolumetricFlowRateUnit
-
US Gallon per hour (gal/h, GPH), commonly used for smaller flow rates in the US.
const VolumetricFlowRateUnit(VolumetricFlowRateFactors.cmpsPerGph, 'gal/h')
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- index → int
-
A numeric identifier for the enumerated value.
no setterinherited
- isMetric → bool
-
Returns
trueonly for cubicMeterPerSecond, the coherent SI derived unit;falsefor the imperial/US customary units, for cubicMeterPerMinute and cubicMeterPerHour (contain the non-metric minute/hour), and for all litre-based units (literPerSecond, literPerMinute, literPerHour, milliliterPerMinute — the litre is accepted for use with the SI but is not metric).no setteroverride - isSI → bool
-
Returns
trueonly for cubicMeterPerSecond, the SI derived unit of volumetric flow rate.no setteroverride - name → String
-
Available on Enum, provided by the EnumName extension
The name of the enum value.no setter - runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- symbol → String
-
A human-readable symbol or abbreviation for the unit.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
-
nameAliases
→ const Map<
String, VolumetricFlowRateUnit> - Case-insensitive name aliases for parsing (all lowercase).
-
symbolAliases
→ const Map<
String, VolumetricFlowRateUnit> - Case-sensitive symbol aliases for parsing.
-
values
→ const List<
VolumetricFlowRateUnit> - A constant List of the values in this enum, in order of their declaration.