voltage_level library
Provides type-safe units for logarithmic voltage levels.
Import this file to use voltage level quantities and their num extensions
(like 0.dBV or 4.dBu).
Classes
-
AffineQuantity<
T extends Unit< T> , Q extends AffineQuantity<T, Q> > - Base class for quantities whose conversions are affine instead of purely multiplicative.
-
InverseQuantity<
T extends Unit< T> , Q extends InverseQuantity<T, Q> > - Base class for quantities whose conversions route through a reciprocal canonical form.
-
LinearQuantity<
T extends LinearUnit< T> , Q extends LinearQuantity<T, Q> > - An abstract base class for physical quantities with linear (factor-based) unit conversions.
-
LinearUnit<
T extends LinearUnit< T> > - A contract for units that scale linearly (via a simple multiplier).
-
LogarithmicQuantity<
T extends Unit< T> , Q extends LogarithmicQuantity<T, Q> > - Base class for quantities that represent logarithmic levels of another physical dimension.
-
Quantity<
T extends Unit< T> > - An abstract representation of a physical quantity, encapsulating a numerical value and a specific unit of measurement.
-
Unit<
T extends Unit< T> > - A base contract for all unit enums.
- VoltageLevel
- Represents an absolute logarithmic voltage level.
Enums
- VoltageLevelUnit
- Represents units of absolute logarithmic voltage level.
Extensions
- VoltageLevelCreation on num
- Provides convenient factory methods for creating VoltageLevel instances.
- VoltageLevelValueGetters on VoltageLevel
- Provides convenient access to VoltageLevel values in specific units.
- VoltageLevelVoltageBridge on VoltageLevel
- Provides bridge helpers from VoltageLevel back to Voltage.
- VoltageVoltageLevelBridge on Voltage
- Provides bridge helpers between Voltage and VoltageLevel.